package com.ruoyi.rocketmq.service;

import java.util.List;
import com.ruoyi.rocketmq.domain.InitialHeartbeatListen;

/**
 * 心跳信息Service接口
 * 
 * @author gyt
 * @date 2025-09-08
 */
public interface IInitialHeartbeatListenService 
{
    /**
     * 查询心跳信息
     * 
     * @param clientId 心跳信息主键
     * @return 心跳信息
     */
    public InitialHeartbeatListen selectInitialHeartbeatListenByClientId(String clientId);

    /**
     * 查询心跳信息列表
     * 
     * @param initialHeartbeatListen 心跳信息
     * @return 心跳信息集合
     */
    public List<InitialHeartbeatListen> selectInitialHeartbeatListenList(InitialHeartbeatListen initialHeartbeatListen);

    /**
     * 新增心跳信息
     * 
     * @param initialHeartbeatListen 心跳信息
     * @return 结果
     */
    public int insertInitialHeartbeatListen(InitialHeartbeatListen initialHeartbeatListen);

    /**
     * 修改心跳信息
     * 
     * @param initialHeartbeatListen 心跳信息
     * @return 结果
     */
    public int updateInitialHeartbeatListen(InitialHeartbeatListen initialHeartbeatListen);

    /**
     * 批量删除心跳信息
     * 
     * @param clientIds 需要删除的心跳信息主键集合
     * @return 结果
     */
    public int deleteInitialHeartbeatListenByClientIds(String[] clientIds);

    /**
     * 删除心跳信息信息
     * 
     * @param clientId 心跳信息主键
     * @return 结果
     */
    public int deleteInitialHeartbeatListenByClientId(String clientId);
}
