package com.ruoyi.rocketmq.controller;

import java.util.List;
import java.io.IOException;
import javax.servlet.http.HttpServletResponse;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.GetMapping;
import org.springframework.web.bind.annotation.PostMapping;
import org.springframework.web.bind.annotation.PutMapping;
import org.springframework.web.bind.annotation.DeleteMapping;
import org.springframework.web.bind.annotation.PathVariable;
import org.springframework.web.bind.annotation.RequestBody;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RestController;
import com.ruoyi.common.log.annotation.Log;
import com.ruoyi.common.log.enums.BusinessType;
import com.ruoyi.common.security.annotation.RequiresPermissions;
import com.ruoyi.rocketmq.domain.InitialHeartbeatListen;
import com.ruoyi.rocketmq.service.IInitialHeartbeatListenService;
import com.ruoyi.common.core.web.controller.BaseController;
import com.ruoyi.common.core.web.domain.AjaxResult;
import com.ruoyi.common.core.utils.poi.ExcelUtil;
import com.ruoyi.common.core.web.page.TableDataInfo;

/**
 * 心跳信息Controller
 * 
 * @author gyt
 * @date 2025-09-08
 */
@RestController
@RequestMapping("/heartbeatListen")
public class InitialHeartbeatListenController extends BaseController
{
    @Autowired
    private IInitialHeartbeatListenService initialHeartbeatListenService;

    /**
     * 查询心跳信息列表
     */
    @RequiresPermissions("rocketmq:heartbeatListen:list")
    @GetMapping("/list")
    public TableDataInfo list(InitialHeartbeatListen initialHeartbeatListen)
    {
        startPage();
        List<InitialHeartbeatListen> list = initialHeartbeatListenService.selectInitialHeartbeatListenList(initialHeartbeatListen);
        return getDataTable(list);
    }

    /**
     * 导出心跳信息列表
     */
    @RequiresPermissions("rocketmq:heartbeatListen:export")
    @Log(title = "心跳信息", businessType = BusinessType.EXPORT)
    @PostMapping("/export")
    public void export(HttpServletResponse response, InitialHeartbeatListen initialHeartbeatListen)
    {
        List<InitialHeartbeatListen> list = initialHeartbeatListenService.selectInitialHeartbeatListenList(initialHeartbeatListen);
        ExcelUtil<InitialHeartbeatListen> util = new ExcelUtil<InitialHeartbeatListen>(InitialHeartbeatListen.class);
        util.exportExcel(response, list, "心跳信息数据");
    }

    /**
     * 获取心跳信息详细信息
     */
    @RequiresPermissions("rocketmq:heartbeatListen:query")
    @GetMapping(value = "/{clientId}")
    public AjaxResult getInfo(@PathVariable("clientId") String clientId)
    {
        return success(initialHeartbeatListenService.selectInitialHeartbeatListenByClientId(clientId));
    }

    /**
     * 新增心跳信息
     */
    @RequiresPermissions("rocketmq:heartbeatListen:add")
    @Log(title = "心跳信息", businessType = BusinessType.INSERT)
    @PostMapping
    public AjaxResult add(@RequestBody InitialHeartbeatListen initialHeartbeatListen)
    {
        return toAjax(initialHeartbeatListenService.insertInitialHeartbeatListen(initialHeartbeatListen));
    }

    /**
     * 修改心跳信息
     */
    @RequiresPermissions("rocketmq:heartbeatListen:edit")
    @Log(title = "心跳信息", businessType = BusinessType.UPDATE)
    @PutMapping
    public AjaxResult edit(@RequestBody InitialHeartbeatListen initialHeartbeatListen)
    {
        return toAjax(initialHeartbeatListenService.updateInitialHeartbeatListen(initialHeartbeatListen));
    }

    /**
     * 删除心跳信息
     */
    @RequiresPermissions("rocketmq:heartbeatListen:remove")
    @Log(title = "心跳信息", businessType = BusinessType.DELETE)
	@DeleteMapping("/{clientIds}")
    public AjaxResult remove(@PathVariable String[] clientIds)
    {
        return toAjax(initialHeartbeatListenService.deleteInitialHeartbeatListenByClientIds(clientIds));
    }
}
